IDF converter is a set of Python tools to convert satellite, in-situ and
numerical model data into Intermediary Data Format, i.e. self-contained,
CF-compliant NetCDF files that are easier to analyse than the original files.

The IDF files produced by the converter can also be visualised using SEAScope,
a viewer which offers advanced rendering functionalities that ease the
detection of synergies between several sources of observations and simulations
(available on Linux, Windows and macOS).

For more information about the Intermediate Data Format (IDF), please read the
`IDF specifications document`_

You can download SEAScope and some examples of IDF files on the
`SEAScope website`_.

.. _IDF specifications document: https://seascope.oceandatalab.com/docs/idf_specifications_1.5.pdf
.. _SEAScope website: https://seascope.oceandatalab.com
